@@ -720,6 +720,10 @@ mod tests {
                 let date = Date::parse("2021-12-15", "yyyy-mm-dd hh24:mi:ss").unwrap();
                 assert_eq!(dt, date);
 
+                let dt = generate_date(2021, 12, 15, 0, 0, 0);
+                let date = Date::parse("2021-12-15", "yyyy-mm-dd hh24-mi-ss").unwrap();
+                assert_eq!(dt, date);
+
                 let dt = generate_date(2021, 12, 15, 11, 0, 0);
                 let date = Date::parse("2021-12-15 11", "yyyy-mm-dd hh24:mi:ss").unwrap();
                 assert_eq!(dt, date);
@@ -741,6 +745,11 @@ mod tests {
                 assert_eq!(dt, date);
             }
 
+            // Can not absence of year\month\day
+            {
+                assert!(Date::parse("2022-4", "yyyy-mm-dd").is_err());
+            }
+
             // Short format
             {
                 let date = generate_date(1234, 8, 6, 7, 8, 9);
